@@ -3,12 +3,10 @@ import numpy as np
 import torch 
 from torch import fft as FFT
 from mrftools import SequenceParameters, DictionaryParameters, Simulation, SequenceType
-import ISMRMRDQuaternionHelper
 import time
 import torchkbnufft as tkbn
 from tqdm import tqdm
-from mrftools import DictionaryEntry
-import CoilCombine
+from mrftools import DictionaryEntry, coilCombination
 import kornia as K
 import nibabel as nib
 import fbpca
@@ -196,7 +194,7 @@ def PerformWalshCoilCombination(images, verbose=False, kernelSize=5, niter=5, de
     t = time.time()
     shape = np.shape(images)
     combinedImageData = torch.zeros((shape[0], shape[2], shape[3], shape[4]), dtype=torch.complex64)
-    coil_map, rho = CoilCombine.calculate_csm_walsh(images[0,:,:,:,:], smoothing=kernelSize, niter=niter) 
+    coil_map, rho = coilCombination.calculate_csm_walsh(images[0,:,:,:,:], smoothing=kernelSize, niter=niter) 
     for svdComponent in np.arange(0,shape[0]):
         im = (images[svdComponent, :, :, :, :]).to(device)
         combinedImageData[svdComponent, :, :, :] = torch.sum((im * torch.conj(coil_map)), axis=0)
@@ -215,7 +213,7 @@ def PerformInatiCoilCombination(images, verbose=False, kernelSize=5, niter=5, de
     t = time.time()
     shape = np.shape(images)
     combinedImageData = torch.zeros((shape[0], shape[2], shape[3], shape[4]), dtype=torch.complex64)
-    coil_map, combinedImageData[0, :, :, :] = CoilCombine.calculate_csm_inati_iter_local(images[0,:,:,:,:], verbose=verbose, smoothing=kernelSize, niter=niter) 
+    coil_map, combinedImageData[0, :, :, :] = coilCombination.calculate_csm_inati_iter_local(images[0,:,:,:,:], verbose=verbose, smoothing=kernelSize, niter=niter) 
     for svdComponent in np.arange(1,shape[0]):
         im = (images[svdComponent, :, :, :, :]).to(device)
         combinedImageData[svdComponent, :, :, :] = torch.sum((im * torch.conj(coil_map)), axis=0)
